<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-mots?lang_cible=oc_ni_mis
// ** ne pas modifier le fichier **

return [

	// M
	'mots_description' => 'Mot e Group de mot',
	'mots_slogan' => 'Gestioun dei mot e group de mot en SPIP',
];
